@@ -1,6 +1,6 @@
 package Net::Stomp::MooseHelpers::ReadTrace;
 {
-  $Net::Stomp::MooseHelpers::ReadTrace::VERSION = '1.3.1';
+  $Net::Stomp::MooseHelpers::ReadTrace::VERSION = '1.1';
 }
 {
   $Net::Stomp::MooseHelpers::ReadTrace::DIST = 'Net-Stomp-MooseHelpers';
@@ -57,20 +57,13 @@ sub read_frame_from_fh {
 }
 
 
-sub trace_subdir_for_destination {
-    my ($self,$destination) = @_;
-
-    return $self->trace_basedir->subdir(
-        Net::Stomp::MooseHelpers::TracerRole->
-              _dirname_from_destination($destination)
-          );
-}
-
-
 sub sorted_filenames {
     my ($self,$destination) = @_;
 
-    my $dir = $self->trace_subdir_for_destination($destination);
+    my $dir = $self->trace_basedir->subdir(
+        Net::Stomp::MooseHelpers::TraceStomp->
+              _dirname_from_destination($destination)
+          );
 
     return unless -e $dir;
 
@@ -89,17 +82,6 @@ sub sorted_filenames {
 }
 
 
-sub clear_destination {
-    my ($self,$destination) = @_;
-
-    my $dir = $self->trace_subdir_for_destination($destination);
-
-    $dir->rmtree;$dir->mkpath;
-
-    return;
-}
-
-
 sub sorted_frames {
     my ($self,$destination) = @_;
 
@@ -111,7 +93,6 @@ sub sorted_frames {
 1;
 
 __END__
-
 =pod
 
 =encoding utf-8
@@ -122,7 +103,7 @@ Net::Stomp::MooseHelpers::ReadTrace - class to read the output of L<Net::Stomp::
 
 =head1 VERSION
 
-version 1.3.1
+version 1.1
 
 =head1 SYNOPSIS
 
@@ -167,17 +148,6 @@ just after it.
 If the file was not a dumped STOMP frame, this function may still
 return a frame, but the contents are probably going to be useless.
 
-=head2 C<trace_subdir_for_destination>
-
-  my $dir = $reader->trace_subdir_for_destination($destination);
-
-Returns a L<Path::Class::Dir> object pointing at the (possibly
-non-existent) directory used to store frames for the given
-destination.
-
-C<< ->trace_subdir_for_destination() >> is the same as C<<
-->trace_basedir >>.
-
 =head2 C<sorted_filenames>
 
   my @names = $reader->sorted_filenames();
@@ -190,17 +160,6 @@ under L</trace_basedir>, sorted by filename (that is, by timestamp).
 If you don't specify a destination, all filenames from all
 destinations will be returned.
 
-=head2 C<clear_destination>
-
-  $reader->clear_destination();
-  $reader->clear_destination($destination);
-
-Given a destination (C</queue/something> or similar), removes all
-stored frames for it.
-
-If you don't specify a destination, all frames for all
-destinations will be removed.
-
 =head2 C<sorted_frames>
 
   my @frames = $reader->sorted_frames();
@@ -221,3 +180,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
