@@ -1,6 +1,6 @@
 package Net::Stomp::MooseHelpers::TraceOnly;
 {
-  $Net::Stomp::MooseHelpers::TraceOnly::VERSION = '1.3.1';
+  $Net::Stomp::MooseHelpers::TraceOnly::VERSION = '1.1';
 }
 {
   $Net::Stomp::MooseHelpers::TraceOnly::DIST = 'Net-Stomp-MooseHelpers';
@@ -14,11 +14,7 @@ use namespace::autoclean;
 with 'Net::Stomp::MooseHelpers::TracerRole';
 
 
-has trace => (
-    is => 'ro',
-    isa => 'Bool',
-    default => 1,
-);
+sub trace { 1 }
 
 around '_build_connection' => sub {
     my ($orig,$self,@etc) = @_;
@@ -31,7 +27,7 @@ around '_build_connection' => sub {
 
 package Net::Stomp::MooseHelpers::TraceOnly::Connection;
 {
-  $Net::Stomp::MooseHelpers::TraceOnly::Connection::VERSION = '1.3.1';
+  $Net::Stomp::MooseHelpers::TraceOnly::Connection::VERSION = '1.1';
 }
 {
   $Net::Stomp::MooseHelpers::TraceOnly::Connection::DIST = 'Net-Stomp-MooseHelpers';
@@ -41,15 +37,7 @@ use Carp;
 
 has _tracing_object => ( is => 'rw' );
 
-sub connect {
-    return Net::Stomp::Frame->new({
-        command => 'CONNECTED',
-        headers => {
-            session => 'ID:foo',
-        },
-        body => '',
-    });
-}
+sub connect { return 1 }
 sub subscribe { return 1 }
 sub unsubscribe { return 1 }
 sub ack { return 1 }
@@ -83,8 +71,9 @@ sub send {
 __PACKAGE__->meta->make_immutable;
 }
 
-__END__
 
+
+__END__
 =pod
 
 =encoding utf-8
@@ -95,7 +84,7 @@ Net::Stomp::MooseHelpers::TraceOnly - role to replace the Net::Stomp connection
 
 =head1 VERSION
 
-version 1.3.1
+version 1.1
 
 =head1 SYNOPSIS
 
@@ -156,3 +145,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
