@@ -1,6 +1,6 @@
 package Net::Stomp::MooseHelpers::TracerRole;
 {
-  $Net::Stomp::MooseHelpers::TracerRole::VERSION = '1.3.1';
+  $Net::Stomp::MooseHelpers::TracerRole::VERSION = '1.1';
 }
 {
   $Net::Stomp::MooseHelpers::TracerRole::DIST = 'Net-Stomp-MooseHelpers';
@@ -34,7 +34,6 @@ sub _dirname_from_destination {
     return '' unless defined $destination;
 
     my $ret = $destination;
-    $ret =~ s{^(queue|topic)/}{/$1/};
     $ret =~ s/\W+/_/g;
     return $ret;
 }
@@ -75,7 +74,6 @@ sub _save_frame {
 1;
 
 __END__
-
 =pod
 
 =encoding utf-8
@@ -86,7 +84,7 @@ Net::Stomp::MooseHelpers::TracerRole - role to dump Net::Stomp frames to disk
 
 =head1 VERSION
 
-version 1.3.1
+version 1.1
 
 =head1 DESCRIPTION
 
@@ -141,3 +139,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
